# Provisioner - Procure Hardware

The provisioner is responsible for:

* Procuring equipment

* Setting up the [Facility](#facility)

* Maintaining stock of supplies in the [Facility](#facility)

* Minimizing hardware supply chain security risks

## Directives

* MUST maintain chain of custody for all hardware until after it's properly stored or where necessary tamper-proofed

The different procedures are ordered in chronological preference, to improve the efficiency of setting up the system.

## Preparing SD Cards

SD cards don't require special chain of custody, but ideally should be purchased from a reputable supplier.

### SD Card Models

{{ #include ../../../../hardware-models.md:sd-models }}

### Notes

* The facility should always be well stocked with freshly formatted SD cards

    * There should be at least 20 microSD and 20 SD cards available for use

    * Both microSD and regular SD cards should be available

    * They should be formatted to `fat32` format

* Usage of these SD cards:

    * Transferring transaction data from online to air-gapped machine

    * Storing tamper proofing evidence produced at the end of the ceremony

### Procedure: formatting SD Card to `fat32`

{{ #include ../../../../component-documents/sd-formatting.md:steps }}

## Tamper Proofing Equipment

### Vacuum Sealer and roll

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-equipment}}

### Colored beads

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-filler}}

### Digital camera

{{ #include ../../../../component-documents/tamper-evidence-methods.md:digital-cameras}}

### Polaroid camera

{{ #include ../../../../component-documents/tamper-evidence-methods.md:polaroid-cameras}}

### Shardfile (SD Card)

There should be multiple SD cards containing the shardfile data. Shardfile data is produced during a [Root Entropy](todo) derivation ceremony.

The Shardfile SD Card once provisioned will be used in creating the [tamper proofed airgap bundle](#air-gapped-bundle)

* Label: "Shardfile"

## Keychain (SD Card)

This procedure requires 2 individuals in order to witness the process and verify that the data being burned to the card is correct.

The Keychain SD Card once provisioned will be used in creating the [tamper proofed airgap bundle](#air-gapped-bundle)

### Procedure

1. Get a freshly formatted SD card 

1. Plug it into a computer

1. Navigate the the official Keychain repository of your organization

1. Select provisioner and approver keys from the Keychain repository

1. Download the desired keys along with detached signatures

1. Copy the `.asc` and signature files to the SD card

1. Use the `sdtool` to lock the card

{{ #include ../../../../sdtool-instructions.md:steps }}

1. Label the card "Keychain <date>"


## Air-gapped bundle

* Tamper proof together the following objects:
    
    * [Air-gapped machine](#computer-procurement)
    
    * [AirgapOS SD card](#airgapos)

    * [Keychain SD card](#trusted-keys)

    * [Shardfile SD card](#shardfile)

### Procedure

{{ #include ../../../../component-documents/tamper-evidence-methods.md:vsbwf-procedure-sealing }}
